ControlHandle

Enum ControlHandle 

pub enum ControlHandle {
    NoHandle,
    Hwnd(HWND),
    Menu(HMENU, HMENU),
    PopMenu(HWND, HMENU),
    MenuItem(HMENU, u32),
    Notice(HWND, u32),
    Timer(HWND, u32),
    SystemTray(HWND),
}
Inner handle type used internally by each control.

Variants



NoHandle



Hwnd(HWND)



Menu(HMENU, HMENU)

(Parent menu / Menu). Parent menu must be there as WINAPI does not have any function to fetch the parent



PopMenu(HWND, HMENU)

(Parent window / Menu).



MenuItem(HMENU, u32)

(Parent menu / Unique ID).



Notice(HWND, u32)

Notice control



Timer(HWND, u32)

Timer control



SystemTray(HWND)

System tray control

Implementations

Source

impl ControlHandle

pub fn destroy(&mut self)

Destroy the underlying object and set the handle to NoHandle Can be used to “reset” a UI component

pub fn blank(&self) -> bool

pub fn hwnd(&self) -> Option<HWND>

pub fn hmenu(&self) -> Option<(HMENU, HMENU)>

pub fn pop_hmenu(&self) -> Option<(HWND, HMENU)>

pub fn hmenu_item(&self) -> Option<(HMENU, u32)>

pub fn timer(&self) -> Option<(HWND, u32)>

pub fn notice(&self) -> Option<(HWND, u32)>

pub fn tray(&self) -> Option<HWND>