MenuSeparator

Struct MenuSeparator 

pub struct MenuSeparator {
    pub handle: ControlHandle,
}
A menu separator. Can be added between two menu item to separte them. Cannot be added to a menubar.

Requires the menu feature.

Builder parameters:

  • parent: A top level window or a menu. With a top level window, the menu item is added to the menu bar.

Control events:

  • OnMenuHover: When the user hovers the menu
use native_windows_gui2 as nwg;

fn separator(sep: &mut nwg::MenuSeparator, menu: &nwg::Menu) -> Result<(), nwg::NwgError> {
    nwg::MenuSeparator::builder()
        .parent(menu)
        .build(sep)
}

Fields

handle: ControlHandle

Implementations

Source

impl MenuSeparator

pub fn builder() -> MenuSeparatorBuilder