ProgressBar

Struct ProgressBar 

pub struct ProgressBar {
    pub handle: ControlHandle,
}
A progress bar is a window that an application can use to indicate the progress of a lengthy operation.

Requires the progress-bar feature.

Builder parameters:

  • parent: Required. The progress bar parent container.
  • size: The progress bar size.
  • position: The progress bar position.
  • state: The initial state of the progress bar.
  • step: The value in which the progress bar value increase when advance is used.
  • pos: The initial value of the progress bar.
  • range: The minimum and maximum value in the progress bar.
  • enabled: If the progress bar is enabled.
  • flags: A combination of the ProgressBarFlags values.
  • ex_flags: A combination of win32 window extended flags. Unlike flags, ex_flags must be used straight from winapi
  • marquee: Enable of disable the marquee animation (only used with the MARQUEE flags)
  • marquee_update: The update interval of the marquee mode

Control events:

  • MousePress(_): Generic mouse press events on the progress bar
  • OnMouseMove: Generic mouse mouse event
  • OnMouseWheel: Generic mouse wheel event
use native_windows_gui2 as nwg;
fn build_progress_bar(bar: &mut nwg::ProgressBar, window: &nwg::Window) {
    nwg::ProgressBar::builder()
        .state(nwg::ProgressBarState::Paused)
        .step(10)
        .range(0..100)
        .parent(window)
        .build(bar);
}

Fields

handle: ControlHandle

Implementations

Source

impl ProgressBar

pub fn builder() -> ProgressBarBuilder

pub fn state(&self) -> ProgressBarState

Return the current state of the progress bar

pub fn set_state(&self, state: ProgressBarState)

Set the state of the progress bar

pub fn advance(&self)

Increase the bar value by the step value

pub fn advance_delta(&self, v: u32)

Increase the bar value by a value

pub fn step(&self) -> u32

Return the step of the progress bar.

pub fn set_step(&self, s: u32)

Set the step of the progress bar.

pub fn pos(&self) -> u32

Return the position of the progress bar.

pub fn set_pos(&self, p: u32)

Set the position of the progress bar. If the value is outside of range sets the value to the nearest bound.

pub fn range(&self) -> Range<u32>

Get the range of the progress bar

pub fn set_range(&self, range: Range<u32>)

Set the range of the progress bar

pub fn set_marquee(&self, enable: bool, update_interval: u32)

Set the progress bar marquee mode

pub fn add_flags(&self, styles: ProgressBarFlags)

Updates the flags of the progress bar.

pub fn remove_flags(&self, styles: ProgressBarFlags)

Removes flags from the progress bar.

pub fn focus(&self) -> bool

Return true if the control currently has the keyboard focus

pub fn set_focus(&self)

Set the keyboard focus on the button.

pub fn enabled(&self) -> bool

Return true if the control user can interact with the control, return false otherwise

pub fn set_enabled(&self, v: bool)

Enable or disable the control

pub fn visible(&self) -> bool

Return true if the control is visible to the user. Will return true even if the control is outside of the parent client view (ex: at the position (10000, 10000))

pub fn set_visible(&self, v: bool)

Show or hide the control to the user

pub fn size(&self) -> (u32, u32)

Return the size of the button in the parent window

pub fn set_size(&self, x: u32, y: u32)

Set the size of the button in the parent window

pub fn position(&self) -> (i32, i32)

Return the position of the button in the parent window

pub fn set_position(&self, x: i32, y: i32)

Set the position of the button in the parent window

pub fn class_name(&self) -> &'static str

Winapi class name used during control creation

pub fn flags(&self) -> u32

Winapi base flags used during window creation

pub fn forced_flags(&self) -> u32

Winapi flags required by the control