TextBox

Struct TextBox 

pub struct TextBox {
    pub handle: ControlHandle,
}
An edit control is a rectangular control window to permit the user to enter and edit text by typing on the keyboard This control allow multi line input. For a single line of text, use TextInput.

Requires the textbox feature.

Note: Use \r\n to input a new line not just \n.

Builder parameters:

  • parent: Required. The text box parent container.
  • text: The text box text.
  • size: The text box size.
  • position: The text box position.
  • flags: A combination of the TextBoxFlags values.
  • ex_flags: A combination of win32 window extended flags. Unlike flags, ex_flags must be used straight from winapi
  • font: The font used for the text box text
  • limit: The maximum number of character that can be inserted in the control
  • readonly: If the textbox should allow user input or not
  • focus: The control receive focus after being created

Control events:

  • OnTextInput: When a TextBox value is changed
  • MousePress(_): Generic mouse press events on the button
  • OnMouseMove: Generic mouse mouse event
  • OnMouseWheel: Generic mouse wheel event
  • OnKeyPress: Generic key press event
  • OnKeyRelease: Generic key release event
use native_windows_gui2 as nwg;
fn build_box(tbox: &mut nwg::TextBox, window: &nwg::Window, font: &nwg::Font) {
    nwg::TextBox::builder()
        .text("Hello")
        .font(Some(font))
        .parent(window)
        .build(tbox);
}

Fields

handle: ControlHandle

Implementations

Source

impl TextBox

pub fn builder<'a>() -> TextBoxBuilder<'a>

pub fn font(&self) -> Option<Font>

Return the font of the control

pub fn set_font(&self, font: Option<&Font>)

Set the font of the control

pub fn limit(&self) -> u32

Return the number of maximum character allowed in this text input

pub fn set_limit(&self, limit: usize)

Set the number of maximum character allowed in this text input

pub fn modified(&self) -> bool

Check if the content of the text input was modified after it’s creation

pub fn set_modified(&self, e: bool)

Manually set modified flag of the text input

pub fn undo(&self)

Undo the last action by the user in the control

pub fn selection(&self) -> Range<u32>

Return the selected range of characters by the user in the text input

pub fn set_selection(&self, r: Range<u32>)

Return the selected range of characters by the user in the text input

pub fn len(&self) -> u32

Return the length of the user input in the control. Performs a newline conversion first since Windows treats “\r\n” as a single character

pub fn linecount(&self) -> i32

Return the number of lines in the multiline edit control. If the control has no text, the return value is 1.

pub fn scroll(&self, v: i32)

Scroll v lines in the multiline edit control.

pub fn scroll_lastline(&self)

Get the linecount and then scroll the text to the last line

pub fn readonly(&self) -> bool

Return true if the TextInput value cannot be edited. Retrurn false otherwise. A user can still copy text from a readonly TextEdit (unlike disabled)

pub fn set_readonly(&self, r: bool)

Set the readonly flag of the text input A user can still copy text from a readonly TextEdit (unlike disabled)

pub fn clear(&self)

Remove all text from the textbox

pub fn focus(&self) -> bool

Return true if the control currently has the keyboard focus

pub fn set_focus(&self)

Set the keyboard focus on the button

pub fn enabled(&self) -> bool

Return true if the control user can interact with the control, return false otherwise

pub fn set_enabled(&self, v: bool)

Enable or disable the control

pub fn visible(&self) -> bool

Return true if the control is visible to the user. Will return true even if the control is outside of the parent client view (ex: at the position (10000, 10000))

pub fn set_visible(&self, v: bool)

Show or hide the control to the user

pub fn size(&self) -> (u32, u32)

Return the size of the button in the parent window

pub fn set_size(&self, x: u32, y: u32)

Set the size of the button in the parent window

pub fn position(&self) -> (i32, i32)

Return the position of the button in the parent window

pub fn set_position(&self, x: i32, y: i32)

Set the position of the button in the parent window

pub fn text(&self) -> String

Return the text displayed in the TextInput

pub fn set_text<'a>(&self, v: &'a str)

Set the text displayed in the TextInput

pub fn set_text_unix2dos<'a>(&self, v: &'a str)

Set the text in the current control, converting unix-style newlines in the input to “\r\n”

pub fn append<'a>(&self, v: &'a str)

Append text to the current control

pub fn appendln<'a>(&self, v: &'a str)

Append text to the current control followed by “\r\n”

pub fn class_name(&self) -> &'static str

Winapi class name used during control creation

pub fn flags(&self) -> u32

Winapi base flags used during window creation

pub fn forced_flags(&self) -> u32

Winapi flags required by the control