pub fn unbind_raw_event_handler(
handler: &RawEventHandler,
) -> Result<(), NwgError>Expand description
Remove the raw event handler from the associated window. Calling unbind twice or trying to unbind an handler after destroying its parent will cause the function to panic.